% -------------------------------------------------------------------------
% Sparsity based methods for feature selection
% l1/l2 regularization
%
% Chiara Olivieri - olivieri@disi.unige.it
%
% Simple demo. For details see l1l2_demo.m
%
% -------------------------------------------------------------------------

clear
close all

addpath(genpath('.'));

fprintf('--- Sparsity based methods for feature selection - l1/l2 regularization ---\n\n');

% -------------------------------------------------------------------------
% Training set generation
% -------------------------------------------------------------------------

N = 30;        % Number of examples
P = 100;       % Number of variables
S = 3;         % Number of relevant variables
% We add a normal distributed error with standard deviation err_y to the
% label vector Y.
err_y = 0.01;

L2_par = 0.1;

L1_n_par = 20;

fprintf('-> Training set generation (%d elements, %d dimensions, %d features)\n', N, P, S);
fx = create_regression_coefficients(P, S);
[X,Y] = create_training_set_new(N, fx, err_y, 'regr');

% -------------------------------------------------------------------------
% K-fold cross-validation training
% -------------------------------------------------------------------------

fprintf('-> K-fold cross-validation for estimating the regularization parameter\n')

[cv_output, model, tau_values] = l1l2_kcv(X, Y, ...
    'smooth_par', L2_par, ...
    'L1_n_par', L1_n_par, ...
    'protocol', 'one_step', ...
    'plot', true);

fprintf('l1l2 regularization - cross-validation error on validation set %f\n', min(cv_output.err_KCV_1step));
fprintf('                    - # of selected features %d\n', sum(model.selected_1step));

% -------------------------------------------------------------------------
% Test phase
% -------------------------------------------------------------------------

fprintf('-> Test phase\n');

[Xtest,Ytest] = create_training_set_new(N, fx, err_y, 'regr');

pred = l1l2_pred(model, Xtest, Ytest);
fprintf('Test error: %f (tau = %f)\n', pred.err_1step, cv_output.tau_opt_1step);

